projectal.entities.activity API documentation

# projectal.entities.activity

View Source

     1from projectal.entity import Entity
     2from projectal.linkers import *
     3
     4
     5class Activity(Entity, ContactLinker, LocationLinker, RebateLinker,
     6               ResourceLinker, StaffLinker, StageLinker, TagLinker):
     7    """
     8    Implementation of the [Activity](https://projectal.com/docs/latest/#tag/Activity) API.
     9    """
    10    _path = 'activity'
    11    _name = 'activity'
    12    _links = [ContactLinker, LocationLinker, RebateLinker,
    13              ResourceLinker, StaffLinker, StageLinker, TagLinker]

class Activity(projectal.entity.Entity, projectal.linkers.ContactLinker, projectal.linkers.LocationLinker, projectal.linkers.RebateLinker, projectal.linkers.ResourceLinker, projectal.linkers.StaffLinker, projectal.linkers.StageLinker, projectal.linkers.TagLinker): View Source

     6class Activity(Entity, ContactLinker, LocationLinker, RebateLinker,
     7               ResourceLinker, StaffLinker, StageLinker, TagLinker):
     8    """
     9    Implementation of the [Activity](https://projectal.com/docs/latest/#tag/Activity) API.
    10    """
    11    _path = 'activity'
    12    _name = 'activity'
    13    _links = [ContactLinker, LocationLinker, RebateLinker,
    14              ResourceLinker, StaffLinker, StageLinker, TagLinker]

Implementation of the Activity API.

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
projectal.linkers.ContactLinker
  link_contact
  unlink_contact
projectal.linkers.LocationLinker
  link_location
  unlink_location
projectal.linkers.RebateLinker
  link_rebate
  unlink_rebate
projectal.linkers.ResourceLinker
  link_resource
  relink_resource
  unlink_resource
projectal.linkers.StaffLinker
  link_staff
  relink_staff
  unlink_staff
projectal.linkers.StageLinker
  link_stage
  unlink_stage
projectal.linkers.TagLinker
  link_tag
  unlink_tag
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy